@@ -12,6 +12,7 @@ x<-ts(x,start=1,end=e,deltat=1)
 tsma<-SMA(tsx,n=m)
 layout(rbind(1,2), heights=c(6,1))
 par(mfrow=c(1,2))
-plot.ts(tsx,xlab="time", ylab="behavior")
-plot.ts(tsma,xlab="time", ylab="Moving Average of behavior")
+DV<-( paste(substitute(behavior)) )
+plot.ts(tsx,xlab="time", ylab=c("moving average  of behavior",DV))
+plot.ts(tsma,xlab="time", ylab=c("moving average  of behavior",DV))
 }
