@@ -36,9 +36,10 @@ function(behavior,phaseX,v1,v2){
   
   numx<-sum(!is.na(behavior))+3
   #graphics.off()
+  DV<-( paste(substitute(behavior)) )
   layout(rbind(1,2), heights=c(6,1))
   
-  plot(iv,cdcl, ylim=c(0,max),lwd=2,type="o",col="red",bty="l", xlab="time", ylab="behavior", main="PAND" )
+  plot(iv,cdcl, ylim=c(0,max),lwd=2,type="o",col="red",bty="l", xlab="time", ylab=c(DV,"behavior"), main="PAND Below" )
   #yo<-readline("Y ordinate for your reference line  " )
  yo=min(A)+.1
   abline(h=yo,col="gray",lwd=3)
