@@ -44,14 +44,30 @@ function(behavior,phaseX,v1,v2){
   writeLines(" ")
   cat(sprintf(l1),"\n")
   writeLines(" ")
+  KendalA<-mkttest(A)
+  
+  
+  pvalue<-round(KendalA[5],4)
+  
   
   tau<-Tau_U(A_data = A, B_data = B,improvement="decrease")
   print(tau)
   
+  if (pvalue <=0.05)
+  { 
+    writeLines(" ")
+    writeLines("Your data has a statistically significant baseline trend...use Tau-BC.")
+  }
+  
+  if (pvalue >0.05)
+  { 
+    writeLines(" ")
+    writeLines("Your data does not have a statistically significant baseline trend...use Tau-U.")
+  }
   writeLines(" ")
   writeLines("*********************** baseline-corrected Tau index (Tarlow 2017)")
   writeLines(" ")
-  taubc<-Tau_BC(A_data = A, B_data = B,improvement="decrease", pretest_trend = .05,Kendall=TRUE)
+  taubc<-Tau_BC(A_data = A, B_data = B,improvement="decrease")
   print(taubc)
   
 }
